todo list
=========

- make several network connection at once for faster detection
- handle network timeouts (abort at the end ?)
- use the egg name instead of the package name? (to avoid setuptools=0.6.12)
